@@ -34,7 +34,7 @@ expect_message(
       queryterm = "SHOULDNOTEXISTATALL",
       register = "CTGOV",
       con = dbc)),
-  "no.*trials found")
+  "found 0 trials")
 
 # test
 expect_message(
@@ -89,15 +89,6 @@ expect_message(
 
 #### ctrLoadQueryIntoDb update ####
 
-# test
-expect_message(
-  suppressWarnings(
-    ctrLoadQueryIntoDb(
-      querytoupdate = "last",
-      verbose = TRUE,
-      con = dbc)),
-  "no.*trials found")
-
 # test
 expect_message(
   suppressWarnings(
@@ -127,43 +118,12 @@ expect_message(
       con = dbc)),
   "Imported or updated ")
 
-# manipulate history to test updating
-# implemented in dbCTRUpdateQueryHistory
-hist <- suppressWarnings(dbQueryHistory(con = dbc))
-hist[nrow(hist), "query-term"] <-
-  sub("(.*&lup_e=).*", "\\112%2F31%2F2011", hist[nrow(hist), "query-term"])
-
-# convert into json object
-json <- jsonlite::toJSON(list("queries" = hist))
-
-# update database
-expect_equal(
-  nodbi::docdb_update(
-    src = dbc,
-    key = dbc$collection,
-    value = as.character(json),
-    query = '{"_id": "meta-info"}'), 1L)
-
-# test
-tmpTest2 <- suppressWarnings(
-  dbQueryHistory(con = dbc))
-expect_message(
-  tmpTest <- suppressWarnings(
-    ctrLoadQueryIntoDb(
-      querytoupdate = "last",
-      verbose = TRUE,
-      con = dbc)),
-  "Imported or updated")
-
-# test
-expect_true(tmpTest$n > rev(tmpTest2[["query-records"]])[[1]])
-
-# test
-expect_true(length(tmpTest$failed) == 0L)
-
-
 #### ctrLoadQueryIntoDb results ####
 
+dbc <- nodbi::src_sqlite(
+  dbname = system.file("extdata", "demo.sqlite", package = "ctrdata"),
+  collection = "my_trials")
+
 # get results
 result <- suppressMessages(
   suppressWarnings(
@@ -180,17 +140,19 @@ result <- suppressMessages(
         "eligibility.maximum_age",
         "location.facility.name",
         "location"
-        ),
+      ),
       con = dbc)
   ))
 
 # test
 expect_equal(
-  rev(
-    sapply(
-      result[["location"]],
-      function(x) length(x[["facility"]][["name"]])))[1:2],
-  c(30, 1))
+  rev(sort(sapply(
+    result[["location"]],
+    function(x) {
+      if (all(is.na(x))) return(0L) else
+        length(x[["facility"]][["name"]])
+    })))
+  [1:2], c(12, 7))
 
 # test
 expect_true("character" == class(result[[
@@ -215,25 +177,16 @@ expect_true("difftime" == class(result[[
 # test
 expect_true(
   any(grepl(" / ", result[["location.facility.name"]])))
+
+# test
 expect_true(
   length(unlist(strsplit(
-    result[["location.facility.name"]], " / "))) >= 32L)
+    result[["location.facility.name"]], " / "))) >= 22L)
 
 # test
 expect_true("list" == class(result[[
   "clinical_results.baseline.group_list.group"]]))
 
-# test
-tmpTest <- c(
-  "clinical_results.baseline", "clinical_results.outcome_list.outcome",
-  "clinical_results.reported_events", "clinical_results.participant_flow",
-  "clinical_results.point_of_contact", "clinical_results.certain_agreements"
-  # not in the downloaded but in other trials:
-  # "clinical_results.limitations_and_caveats"
-  )
-expect_true(
-  length(setdiff(tmpTest, names(result))) == 0L)
-
 # convert to long
 df <- suppressMessages(
   dfTrials2Long(
@@ -248,30 +201,7 @@ expect_identical(
 
 # test
 expect_true(
-  nrow(df) > 800L
-)
-
-# select value from
-# measure in where
-df2 <- suppressMessages(
-  dfName2Value(
-    df = df,
-    valuename = paste0(
-      "clinical_results.*category_list.category.measurement_list.measurement.value|",
-      "clinical_results.outcome_list.outcome.measure.units"
-    ),
-    wherename = "clinical_results.outcome_list.outcome.measure.title",
-    wherevalue = "duration of response"
-  ))
-
-# test
-expect_true(
-  any("NCT01471782" %in% df2[["_id"]])
-)
-
-# test
-expect_true(
-  all(grepl("5", df2[["identifier"]][ df2[["_id"]] == "NCT01471782" ]))
+  nrow(df) > 1000L
 )
 
 # test
@@ -292,7 +222,7 @@ if (!length(dbc$url) || grepl("localhost", dbc$url)) {
   expect_message(
     suppressWarnings(
       ctrLoadQueryIntoDb(
-        queryterm = "cond=Neuroblastoma&type=Intr&recrs=e&phase=1&u_prot=Y&u_sap=Y&u_icf=Y",
+        queryterm = "cond=Neuroblastoma&type=Intr&recrs=e&phase=0&u_prot=Y&u_sap=Y&u_icf=Y",
         register = "CTGOV",
         documents.path = newTempDir(),
         documents.regexp = ".*",
@@ -314,66 +244,48 @@ expect_equal(
   "")
 
 # get all field names
-tmpf <- suppressMessages(
+tmpFields <- suppressMessages(
   suppressWarnings(
     dbFindFields(
       namepart = ".*",
       con = dbc)))
 
-# get all data
-result <- suppressMessages(
-  suppressWarnings(
-    dbGetFieldsIntoDf(
-      fields = tmpf,
-      con = dbc,
-      verbose = FALSE,
-      stopifnodata = FALSE)
-  ))
-
-# develop
-# print(length(names(result)))
-
 # test
 expect_true(
-  length(names(result)) > 150L)
+  length(tmpFields) > 150L)
+
+#### dbGetFieldsIntoDf ####
+
+groupsNo <- (length(tmpFields) %/% 49L) + 1L
+groupsNo <- rep(seq_len(groupsNo), 49L)
+groupsNo <- groupsNo[1:length(tmpFields)]
+
+for (i in unique(groupsNo)) {
+  message(i, " ", appendLF = FALSE)
+  tmpData <- dbGetFieldsIntoDf(fields = tmpFields[groupsNo == i], con = dbc)
+  expect_true(nrow(tmpData) > 0L)
+  expect_true(ncol(tmpData) > 0L)
+}
+
+tmpFields <- tmpFields[grepl("date$",tmpFields, ignore.case = TRUE)]
+tmpFields <- tmpFields[1:min(length(tmpFields), 49L)]
+
+tmpData <- dbGetFieldsIntoDf(fields = tmpFields, con = dbc)
+expect_true(nrow(tmpData) > 0L)
+expect_true(ncol(tmpData) > 0L)
+
+expect_true(all(
+  unique(unlist(
+    lapply(
+      tmpData[, -1, drop = FALSE],
+      function(i) sapply(i, function(ii) class(ii)))
+  )) %in%
+    c("Date", "POSIXct", "POSIXt")
+))
 
 # determine all classes
-tmpr <- names(result)
-tmpr <- tmpr[tmpr != "_id"]
-tmpc <- sapply(result, class, USE.NAMES = FALSE)
-tmpc <- unlist(tmpc)
-tmpc <- table(tmpc)
-
-# develop
-#
-# print(tmpc)
-#
-# 2022-02-20
-#
-# tinytest::run_test_file("inst/tinytest/test_ctrdata_mongo_local_ctgov.R") # 155
-# Downloading: 8.3 kB     tmpcov.R    0 tests
-# character data.frame       Date   difftime    integer       list    logical
-# 116          4          7          1          2         82          5
-# test_ctrdata_mongo_local_ctgov.R   34 tests OK 12.2s
-# All ok, 34 results (12.2s)
-# > tinytest::run_test_file("inst/tinytest/test_ctrdata_mongo_remote_rw_ctgov.R") # 155
-# Downloading: 8.3 kB     tmpc_ctgov.R    0 tests
-# character data.frame       Date   difftime    integer       list    logical
-# 116          4          7          1          2         82          5
-# test_ctrdata_mongo_remote_rw_ctgov.R   34 tests OK 41.7s
-# All ok, 34 results (41.7s)
-# > tinytest::run_test_file("inst/tinytest/test_ctrdata_postgres_ctgov.R") # 155
-# Downloading: 8.3 kB     tmpcR.    0 tests
-# character      Date  difftime   integer      list   logical
-# 138         7         1         2        73        14
-# test_ctrdata_postgres_ctgov.R.   34 tests OK 22.7s
-# All ok, 34 results (22.7s)
-# > tinytest::run_test_file("inst/tinytest/test_ctrdata_sqlite_ctgov.R") # 155
-# Downloading: 8.3 kB     tmpc..    0 tests
-# character      Date  difftime   integer      list   logical
-# 134         7         1         2        59        32
-# test_ctrdata_sqlite_ctgov.R...   34 tests OK 21.8s
-# All ok, 34 results (21.8s)
-
-# clean up
-rm(df, df2, tmpf, result, tmpc)
+# tmpr <- names(result)
+# tmpr <- tmpr[tmpr != "_id"]
+# tmpc <- sapply(result, class, USE.NAMES = FALSE)
+# tmpc <- unlist(tmpc)
+# tmpc <- table(tmpc)
